@@ -393,9 +393,11 @@ def transformer_wrapper(transformer) -> FuncWrapper:
     
     def wrap_transformer(X):
         try:
-            return transformer.transform(X)
+            res = transformer.transform(X)
+            print("Transforming")
+            return res
         except:
-            # print("Fitting")
+            print("Fitting + Transforming")
             return transformer.fit_transform(X)
 
     wrap_transformer.__name__ = "[wrapped_transformer]__" + transformer.__repr__()
